| Title: | Matrix-Variate Non-Gaussian Linear Regression Models |
|---|---|
| Description: | Fits matrix-variate variance-gamma (MVVG) and matrix-variate normal-inverse-Gaussian (MVNIG) linear regression models using expectation-conditional maximization (ECM) algorithms. The models accommodate clustered matrix-valued responses, with unequal numbers of observations across subjects, correlated responses, skewness, and within-subject dependence. Functions are provided for model fitting, prediction, and subject-level influence assessment using approximate generalized Cook's distances. The package also includes motivating periodontal data from Gullah-speaking African Americans with Type-II diabetes. For details on the underlying matrix-variate distributions (MVVG and MVNIG), see Gallaugher and McNicholas (2019, <doi:10.1016/j.spl.2018.08.012>). |
| Authors: | Samuel Soon [aut, cre], Dipankar Bandyopadhyay [aut], Qingyang Liu [aut] |
| Maintainer: | Samuel Soon <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-07-23 10:33:58 UTC |
| Source: | https://github.com/cran/MVNGmod |
This function calculates influence statistics for each element of the data list using a one-step approximation to the generalized Cook's distance.
case_del(Y, X, mod)case_del(Y, X, mod)
Y |
List of |
X |
List of |
mod |
Model object returned by a call to |
Computes influence statistics for the MVVG and MVNIG models using a one-step approximation to the generalized Cook's distance, based on the score and hessian matrices of the complete-data log-likelihood.
where
is the complete-data score function with the th subject deleted and evaluated in , and
is the complete-data Hessian matrix, as given in Lachos et al. (2015) doi:10.1016/j.jmva.2015.06.014
case_del returns a vector containing the approximate generalized Cook's distance for each corresponding subject in the provided dataset.
Samuel Soon
Dipankar Bandyopadhyay
Qingyang Liu
mod <- MVNIGmod(Y,X,theta_mvnig) case_del(Y,X,mod)mod <- MVNIGmod(Y,X,theta_mvnig) case_del(Y,X,mod)
These data sets describe periodontal measurements performed on members of the Gullah-Speaking African American community.
gaad_covgaad_cov
Each is a list of matrices, with rows denoting tooth sites and columns denoting CAL/PPD response.
gaad_res and gaad_cov contain the response and covariate matrices of the GAAD data.
gaad_cov gaad_resgaad_cov gaad_res
These data sets describe periodontal measurements performed on members of the Gullah-Speaking African American community.
gaad_resgaad_res
Each is a list of matrices, with rows denoting tooth sites and columns denoting CAL/PPD response.
gaad_res and gaad_cov contain the response and covariate matrices of the GAAD data.
gaad_cov gaad_resgaad_cov gaad_res
This is an example of the format of input parameter list theta.
gaad_theta_mvvggaad_theta_mvvg
List of model parameters.
gaad_theta_mvvggaad_theta_mvvg
This function fits MVNIG linear models for matrix-variate skew data with non-uniform data rows between subjects. Exchangeable observation row correlation and skewness structures are imposed to accommodate the varying row counts across matrices. Note that multiple restarts may be needed to account for unstable local maxima.
MVNIGmod(Y, X, theta_g = NULL, stopping = 0.001, max_iter = 50)MVNIGmod(Y, X, theta_g = NULL, stopping = 0.001, max_iter = 50)
Y |
List of |
X |
List of |
theta_g |
List of parameters to pass as initial values in the ECM algorithm. If NULL, will be randomly generated. See Details for an in-depth explanation. |
stopping |
Stopping threshold for the L-infinity norm of differences in consecutive parameter space, evaluated at iteration |
max_iter |
Maximum number of iterations, default is 50. |
Fits the matrix-variate skew regression model
where each response is a matrix that indexes observations and response variables. corresponds to a design matrix, and corresponds to a coefficient matrix. corresponds to a error matrix, following a matrix-variate variance-gamma distribution.
The model estimates MVVG parameters using the alternating expectation conditional maximization (ECM) algorithm, using the density
where , ,
, , and is the modified Bessel function of the second kind.
The structure of theta_g and parameter estimates returned by the function must be in the form of a list with the following named elements:
Theta: coefficient matrix
a: skewness vector
rho: Compound symmetry parameter for row correlation matrix
Psi: column covariance matrix
tgamma: Univariate mixing parameter
MVNIGmod returns a list with the following elements:
Iteration: Number of iterations taken to convergence. Inf if convergence not reached.
Starting Value: List of initial parameter values.
Final Value: List of final parameter estimates.
Stopping Criteria: Vector of at each iteration.
AIC: Model AIC
BIC: Model BIC
Samuel Soon
Dipankar Bandyopadhyay
Qingyang Liu
MVNIGmod(Y,X,theta_mvnig)MVNIGmod(Y,X,theta_mvnig)
This function fits MVVG linear models for matrix-variate skew data with non-uniform data rows between subjects. Exchangeable observation row correlation and skewness structures are imposed to accommodate the varying row counts across matrices. Note that multiple restarts may be needed to account for unstable local maxima.
MVVGmod(Y, X, theta_g = NULL, stopping = 0.001, max_iter = 50)MVVGmod(Y, X, theta_g = NULL, stopping = 0.001, max_iter = 50)
Y |
List of |
X |
List of |
theta_g |
List of parameters to pass as initial values in the ECM algorithm. If NULL, will be randomly generated. See Details for an in-depth explanation. |
stopping |
Stopping threshold for the L-infinity norm of differences in consecutive parameter space, evaluated at iteration |
max_iter |
Maximum number of iterations, default is 50. |
Fits the matrix-variate skew regression model
where each response is a matrix that indexes observations and response variables. corresponds to a design matrix, and corresponds to a coefficient matrix. corresponds to a error matrix, following a matrix-variate variance-gamma distribution.
The model estimates MVVG parameters using the alternating expectation conditional maximization (ECM) algorithm, using the density
where , ,
, , and is the modified Bessel function of the second kind.
The structure of theta_g and parameter estimates returned by the function must be in the form of a list with the following named elements:
Theta: coefficient matrix
a: skewness vector
rho: Compound symmetry parameter for row correlation matrix
Psi: column covariance matrix
gamma: Univariate mixing parameter
MVVGmod returns a list with the following elements:
Iteration: Number of iterations taken to convergence. Inf if convergence not reached.
Starting Value: List of initial parameter values.
Final Value: List of final parameter estimates.
Stopping Criteria: Vector of at each iteration.
AIC: Model AIC
BIC: Model BIC
Samuel Soon
Dipankar Bandyopadhyay
Qingyang Liu
MVVGmod(Y,X,theta_mvvg)MVVGmod(Y,X,theta_mvvg)
Predicts response values given a list of covariate matrices and a model output from either MVVGmod or MVNIGmod.
predict(mod, X)predict(mod, X)
mod |
object outputted by either |
X |
Inputted covariate matrix |
Returns a list of predicted response matrices
Samuel Soon
Dipankar Bandyopadhyay
Qingyang Liu
set.seed(1234) mvnig_mod <- MVNIGmod(Y,X,theta_mvnig) predict(mvnig_mod,X)set.seed(1234) mvnig_mod <- MVNIGmod(Y,X,theta_mvnig) predict(mvnig_mod,X)
Part of toy dataset for examples.
theta_mvnigtheta_mvnig
List of parameters for input to MVNIGmod function
theta_mvvgtheta_mvvg
Part of toy dataset for examples.
theta_mvvgtheta_mvvg
List of parameters for input to MVVGmod function
theta_mvvgtheta_mvvg
Part of toy dataset for examples.
XX
List of covariate matrices for individual subjects
XX
Part of toy dataset for examples.
YY
List of response matrices for individual subjects
YY